Revert "Enable MSAA on Gen8 Intel GPUs"

This reverts commit 0bda1cc640f301f134bad883aa78a926efff756a.

Reason for revert: Performance gap is fairly large.

Original change's description:
> Enable MSAA on Gen8 Intel GPUs
> 
> Bug: skia:9225 chromium:527565
> 
> Change-Id: I7c543bce011c247cd93cad90aca15c9754678202
> Reviewed-on: https://skia-review.googlesource.com/c/skia/+/225731
> Reviewed-by: Brian Salomon <bsalomon@google.com>
> Commit-Queue: Brian Osman <brianosman@google.com>

TBR=bsalomon@google.com,benjaminwagner@google.com,brianosman@google.com

Change-Id: I0e7f0bd53fbdcad0276462852021b9f3adc8ff6e
No-Presubmit: true
No-Tree-Checks: true
No-Try: true
Bug: skia:9225 chromium:527565
Reviewed-on: https://skia-review.googlesource.com/c/skia/+/226076
Reviewed-by: Brian Osman <brianosman@google.com>
Commit-Queue: Brian Osman <brianosman@google.com>
diff --git a/infra/bots/recipes/perf.py b/infra/bots/recipes/perf.py
index 86d481d..bb16a0c 100644
--- a/infra/bots/recipes/perf.py
+++ b/infra/bots/recipes/perf.py
@@ -89,13 +89,8 @@
           'Nexus7'      in bot):
         sample_count = ''
     elif 'Intel' in bot:
-      # We don't want to test MSAA on older Intel chipsets. These are all newer (Gen8/9).
-      if ('Iris655'       not in bot and  # Gen9
-          'Iris640'       not in bot and
-          'Iris540'       not in bot and
-          'IntelHD405'    not in bot and  # Gen8
-          'IntelHD6000'   not in bot and
-          'IntelIris6100' not in bot):
+      # We don't want to test MSAA on older Intel chipsets. These are all newer (Gen9).
+      if 'Iris655' not in bot and 'Iris640' not in bot and 'Iris540' not in bot:
         sample_count = ''
     elif 'ChromeOS' in bot:
       gl_prefix = 'gles'
diff --git a/infra/bots/recipes/test.expected/Test-Debian9-Clang-NUC5PPYH-GPU-IntelHD405-x86_64-Release-All-Vulkan.json b/infra/bots/recipes/test.expected/Test-Debian9-Clang-NUC5PPYH-GPU-IntelHD405-x86_64-Release-All-Vulkan.json
index 858ef6c..9db1661 100644
--- a/infra/bots/recipes/test.expected/Test-Debian9-Clang-NUC5PPYH-GPU-IntelHD405-x86_64-Release-All-Vulkan.json
+++ b/infra/bots/recipes/test.expected/Test-Debian9-Clang-NUC5PPYH-GPU-IntelHD405-x86_64-Release-All-Vulkan.json
@@ -445,7 +445,6 @@
       "_",
       "filltypespersp",
       "--match",
-      "~^SRGBReadWritePixels$",
       "~^ClearOp$",
       "~^CopySurface$",
       "~^ImageNewShader_GPU$",
diff --git a/infra/bots/recipes/test.expected/Test-Mac10.14-Clang-MacBookAir7.2-GPU-IntelHD6000-x86_64-Debug-All.json b/infra/bots/recipes/test.expected/Test-Mac10.14-Clang-MacBookAir7.2-GPU-IntelHD6000-x86_64-Debug-All.json
index 7c39df0..fdc21c1 100644
--- a/infra/bots/recipes/test.expected/Test-Mac10.14-Clang-MacBookAir7.2-GPU-IntelHD6000-x86_64-Debug-All.json
+++ b/infra/bots/recipes/test.expected/Test-Mac10.14-Clang-MacBookAir7.2-GPU-IntelHD6000-x86_64-Debug-All.json
@@ -268,7 +268,6 @@
       "gl",
       "gldft",
       "glsrgb",
-      "glmsaa8",
       "--src",
       "tests",
       "gm",
@@ -505,7 +504,6 @@
       "_",
       ".SRW",
       "--match",
-      "~^SRGBReadWritePixels$",
       "~^ProcessorCloneTest$",
       "~^GrMeshTest$",
       "--nonativeFonts",
diff --git a/infra/bots/recipes/test.expected/Test-Win10-Clang-NUC5i7RYH-GPU-IntelIris6100-x86_64-Release-All-ANGLE.json b/infra/bots/recipes/test.expected/Test-Win10-Clang-NUC5i7RYH-GPU-IntelIris6100-x86_64-Release-All-ANGLE.json
index 379f0ce..3bf740f 100644
--- a/infra/bots/recipes/test.expected/Test-Win10-Clang-NUC5i7RYH-GPU-IntelIris6100-x86_64-Release-All-ANGLE.json
+++ b/infra/bots/recipes/test.expected/Test-Win10-Clang-NUC5i7RYH-GPU-IntelIris6100-x86_64-Release-All-ANGLE.json
@@ -276,8 +276,6 @@
       "angle_d3d9_es2",
       "angle_gl_es2",
       "angle_d3d11_es3",
-      "angle_d3d11_es2_msaa8",
-      "angle_d3d11_es3_msaa8",
       "--src",
       "tests",
       "gm",
diff --git a/infra/bots/recipes/test.py b/infra/bots/recipes/test.py
index 029b4c3..967d4e0 100644
--- a/infra/bots/recipes/test.py
+++ b/infra/bots/recipes/test.py
@@ -127,13 +127,8 @@
       if 'NVIDIA_Shield' not in bot:
         gl_prefix = 'gles'
     elif 'Intel' in bot:
-      # We don't want to test MSAA on older Intel chipsets. These are all newer (Gen8/9).
-      if ('Iris655'       not in bot and  # Gen9
-          'Iris640'       not in bot and
-          'Iris540'       not in bot and
-          'IntelHD405'    not in bot and  # Gen8
-          'IntelHD6000'   not in bot and
-          'IntelIris6100' not in bot):
+      # We don't want to test MSAA on older Intel chipsets. These are all newer (Gen9).
+      if 'Iris655' not in bot and 'Iris640' not in bot and 'Iris540' not in bot:
         sample_count = ''
     elif 'ChromeOS' in bot:
       gl_prefix = 'gles'
@@ -707,11 +702,7 @@
   if api.vars.is_linux and 'IntelIris640' in bot:
     match.extend(['~GLPrograms']) # skia:7849
 
-  if ('IntelIris640'       in bot or
-      'IntelHD615'         in bot or
-      'IntelHDGraphics615' in bot or
-      'IntelHD6000'        in bot or
-      'IntelHD405'         in bot):
+  if 'IntelIris640' in bot or 'IntelHD615' in bot or 'IntelHDGraphics615' in bot:
     match.append('~^SRGBReadWritePixels$') # skia:9225
 
   if 'Vulkan' in bot and api.vars.is_linux and 'IntelHD405' in bot:
diff --git a/src/gpu/gl/GrGLCaps.cpp b/src/gpu/gl/GrGLCaps.cpp
index cfb5bfe..f28ad2a 100644
--- a/src/gpu/gl/GrGLCaps.cpp
+++ b/src/gpu/gl/GrGLCaps.cpp
@@ -1096,10 +1096,10 @@
         fMSFBOType = kNone_MSFBOType;
     }
 
     // We disable MSAA for older (pre-Gen8) Intel GPUs for performance reasons.
     // CherryView (aka Braswell) is the first Gen8 chipset.
     if (kIntel_GrGLVendor == ctxInfo.vendor() &&
-        (ctxInfo.renderer() < kIntelCherryView_GrGLRenderer ||
+        (ctxInfo.renderer() < kIntelApolloLake_GrGLRenderer ||
          ctxInfo.renderer() == kOther_GrGLRenderer)) {
         fMSFBOType = kNone_MSFBOType;
     }
@@ -1096,10 +1096,10 @@
     }
 
-    // We disable MSAA for older (pre-Gen8) Intel GPUs for performance reasons.
-    // CherryView (aka Braswell) is the first Gen8 chipset.
+    // We disable MSAA for older (pre-Gen9) Intel GPUs for performance reasons.
+    // ApolloLake is the first Gen9 chipset.
     if (kIntel_GrGLVendor == ctxInfo.vendor() &&